@@ -25,19 +25,21 @@
  */
 
 #include <config.h>
+
+#include <math.h>
 #include <string.h>
 #include <time.h>
 
-#include <math.h>
 #include <cairo.h>
+
+#include <glib/gi18n.h>
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
+
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 #include <gconf/gconf-client.h>
-#include <libgnomeui/gnome-help.h>
-#include <libgnomeui/gnome-uidefs.h>
 #include <glade/glade-xml.h>
 
 #define FISH_APPLET(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), \
@@ -143,33 +145,56 @@ static void
 show_help (FishApplet *fish, const char *link_id)
 {
 	GError *error = NULL;
+	char   *uri;
+#define FISH_HELP_DOC "fish"
 
-	gnome_help_display_desktop_on_screen (
-		NULL, "fish", "fish", link_id,
-		gtk_widget_get_screen (GTK_WIDGET (fish)),
-		&error);
+	if (link_id)
+		uri = g_strdup_printf ("ghelp:%s?%s", FISH_HELP_DOC, link_id);
+	else
+		uri = g_strdup_printf ("ghelp:%s", FISH_HELP_DOC);
 
-	if (error) {
+	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (fish)), uri,
+		      gtk_get_current_event_time (), &error);
+
+	g_free (uri);
+
+	if (error &&
+	    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+		g_error_free (error);
+	else if (error) {
 		GtkWidget *dialog;
+		char      *primary;
 
+		primary = g_markup_printf_escaped (
+				_("Could not display help document '%s'"),
+				FISH_HELP_DOC);
 		dialog = gtk_message_dialog_new (
 				NULL,
 				GTK_DIALOG_DESTROY_WITH_PARENT,
 				GTK_MESSAGE_ERROR,
 				GTK_BUTTONS_OK,
-				_("There was an error displaying help: %s"),
-				error->message);
+				primary);
+
+		gtk_message_dialog_format_secondary_text (
+					GTK_MESSAGE_DIALOG (dialog),
+					"%s", error->message);
+
+		g_error_free (error);
+		g_free (primary);
 
 		g_signal_connect (dialog, "response",
 				  G_CALLBACK (gtk_widget_destroy),
 				  NULL);
 
 		gtk_window_set_icon_name (GTK_WINDOW (dialog), FISH_ICON);
-		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 		gtk_window_set_screen (GTK_WINDOW (dialog),
 				       gtk_widget_get_screen (GTK_WIDGET (fish)));
+		/* we have no parent window */
+		gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dialog), FALSE);
+		gtk_window_set_title (GTK_WINDOW (dialog),
+				      _("Error displaying help document"));
+
 		gtk_widget_show (dialog);
-		g_error_free (error);
 	}
 }
 
@@ -926,15 +951,15 @@ display_fortune_dialog (FishApplet *fish)
 
 		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (fish->fortune_dialog)->vbox), 
 				    fish->fortune_label,
-				    FALSE, FALSE, GNOME_PAD);
+				    FALSE, FALSE, 6);
 
 		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (fish->fortune_dialog)->vbox), 
 				    scrolled,
-				    TRUE, TRUE, GNOME_PAD);
+				    TRUE, TRUE, 6);
 
 		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (fish->fortune_dialog)->vbox), 
 				    fish->fortune_cmd_label,
-				    FALSE, FALSE, GNOME_PAD);
+				    FALSE, FALSE, 6);
 
 		update_fortune_dialog (fish);
 
@@ -950,7 +975,7 @@ display_fortune_dialog (FishApplet *fish)
 		char *command;
 		char * text;
 
-		command = g_strdup_printf ("<tt>%s</tt>", argv[0]);
+		command = g_markup_printf_escaped ("<tt>%s</tt>", argv[0]);
 		text = g_strdup_printf (_("The configured command is not "
 					  "working and has been replaced by: "
 					  "%s"), command);
@@ -1134,7 +1159,7 @@ static char *
 get_location (void)
 {
 	static char  location [256];
-	char         buffer [256];
+	char        *buffer;
 	FILE        *zone;
 	int          i, len, count;
 	
@@ -1147,18 +1172,22 @@ get_location (void)
 	} 
 
 	/* New method : works for glibc 2.2 */
-	len = readlink ("/etc/localtime", buffer, sizeof (buffer));
-	if (len <= 0)
+	/* FIXME: this is broken for many distros, see the clock code */
+	buffer = g_file_read_link ("/etc/localtime", NULL);
+	if (!buffer)
 		return NULL;
 
 	for (i = len, count = 0; (i > 0) && (count != 2); i--)
 		if (buffer [i] == '/')
 			count++;
 
-	if (count != 2)
+	if (count != 2) {
 		return NULL;
+		g_free (buffer);
+	}
 
 	memcpy (location, &buffer [i + 2], len - i - 2);
+	g_free (buffer);
 
 	return location;
 }
