@@ -14,6 +14,8 @@
 #include <glib/gi18n.h>
 #include <gdk/gdkx.h>
 
+#include <libpanel-util/panel-show.h>
+
 #include "button-widget.h"
 #include "drawer.h"
 #include "launcher.h"
@@ -154,7 +156,7 @@ panel_applet_recreate_menu (AppletInfo	*info)
 		menu->submenu =NULL;
 	}
 
-	gtk_widget_unref (info->menu);
+	g_object_unref (info->menu);
 	info->menu = panel_applet_create_menu (info);
 }
 
@@ -247,7 +249,8 @@ applet_callback_callback (GtkWidget      *widget,
 
 			panel_properties_dialog_present (drawer->toplevel);
 		} else if (strcmp (menu->name, "help") == 0) {
-			panel_show_help (screen, "user-guide.xml", "gospanel-18");
+			panel_show_help (screen,
+					 "user-guide", "gospanel-18", NULL);
 		}
 		break;
 	case PANEL_OBJECT_MENU:
@@ -469,8 +472,7 @@ panel_applet_create_menu (AppletInfo *info)
 
 	panel_widget = PANEL_WIDGET (info->widget->parent);
 
-	menu = g_object_ref (gtk_menu_new ());
-	gtk_object_sink (GTK_OBJECT (menu));
+	menu = g_object_ref_sink (gtk_menu_new ());
 
 	/* connect the show & deactivate signal, so that we can "disallow" and
 	 * "re-allow" autohide when the menu is shown/deactivated.
