@@ -2,7 +2,7 @@
 #define APPLET_H
 
 #include <glib.h>
-#include <gdk/gdktypes.h>
+#include <gdk/gdk.h>
 #include "panel-widget.h"
 #include "panel-gconf.h"
 #include "panel-enums.h"
@@ -57,7 +57,7 @@ AppletInfo *panel_applet_register    (GtkWidget       *applet,
 const char *panel_applet_get_id           (AppletInfo      *info);
 const char *panel_applet_get_id_by_widget (GtkWidget       *widget);
 AppletInfo *panel_applet_get_by_id        (const char      *id);
-AppletInfo *panel_applet_get_by_type      (PanelObjectType  object_type);
+AppletInfo *panel_applet_get_by_type      (PanelObjectType  object_type, GdkScreen *screen);
 
 GSList     *panel_applet_list_applets (void);
 
