@@ -275,6 +275,7 @@ panel_create_menu (void)
 	}
 	
 	retval = gtk_menu_new ();
+	gtk_widget_set_name (retval, "gnome-panel-main-menu");
 	
 	panel_gconf_notify_add_while_alive ("/desktop/gnome/interface/menus_have_icons",
 					    (GConfClientNotifyFunc) menus_have_icons_changed,
@@ -1915,8 +1916,7 @@ panel_load_menu_image_deferred (GtkWidget   *image_menu_item,
 	image->requisition.height = icon_height;
 
 	/* this takes over the floating ref */
-	icon->pixmap = g_object_ref (G_OBJECT (image));
-	gtk_object_sink (GTK_OBJECT (image));
+	icon->pixmap = g_object_ref_sink (G_OBJECT (image));
 
 	icon->stock_id       = stock_id;
 	if (gicon)
