@@ -33,7 +33,9 @@
 #include <glib/gi18n.h>
 
 #include <libpanel-util/panel-error.h>
+#include <libpanel-util/panel-launch.h>
 #include <libpanel-util/panel-session-manager.h>
+#include <libpanel-util/panel-show.h>
 
 #include "applet.h"
 #include "panel-config-global.h"
@@ -216,23 +218,11 @@ static void
 panel_action_search (GtkWidget *widget)
 {
 	GdkScreen *screen;
-	GError    *error = NULL;
 
 	screen = gtk_widget_get_screen (widget);
-	panel_launch_desktop_file ("gnome-search-tool.desktop",
-				   "gnome-search-tool",
-				   screen,
-				   &error);
-	if (error) {
-		char *primary;
-		primary = g_strdup_printf (_("Could not execute '%s'"),
-					   "gnome-search-tool");
-		panel_error_dialog (NULL, screen,
-				    "cannot_exec_gnome-search-tool", TRUE,
-				    primary, error->message);
-		g_free (primary);
-		g_error_free (error);
-	}
+	panel_launch_desktop_file_with_fallback ("gnome-search-tool.desktop",
+						 "gnome-search-tool",
+						 screen, NULL);
 }
 
 /* Force Quit
@@ -307,7 +297,7 @@ static PanelAction actions [] = {
 		PANEL_ICON_LOGOUT,
 		/* when changing one of those two strings, don't forget to
 		 * update the ones in panel-menu-items.c (look for
-		 * panel:showusername|1) */
+		 * "1" (msgctxt: "panel:showusername")) */
 		N_("Log Out..."),
 		N_("Log out of this session to log in as a different user"),
 		"gospanel-20",
@@ -349,7 +339,7 @@ static PanelAction actions [] = {
 		PANEL_ICON_REMOTE, //FIXME icon
 		N_("Connect to Server..."),
 		N_("Connect to a remote computer or shared disk"),
-		"gospanel-563", //FIXME
+		"nautilus-server-connect",
 		"ACTION:connect-server:NEW",
 		panel_action_connect_server, NULL, NULL, NULL
 	},
@@ -827,8 +817,8 @@ panel_action_button_invoke_menu (PanelActionButton *button,
 
 		screen = gtk_widget_get_screen (GTK_WIDGET (button));
 
-		panel_show_help (screen, "user-guide.xml",
-				 actions [button->priv->type].help_index);
+		panel_show_help (screen, "user-guide",
+				 actions [button->priv->type].help_index, NULL);
 
 		return;
 	}
