@@ -42,6 +42,7 @@
 #include <libpanel-util/panel-error.h>
 #include <libpanel-util/panel-glib.h>
 #include <libpanel-util/panel-keyfile.h>
+#include <libpanel-util/panel-launch.h>
 #include <libpanel-util/panel-show.h>
 
 #include "menu.h"
@@ -964,9 +965,8 @@ panel_place_menu_item_create_menu (PanelPlaceMenuItem *place_item)
 				PANEL_ICON_DESKTOP, NULL,
 				/* Translators: Desktop is used here as in
 				 * "Desktop Folder" (this is not the Desktop
-				 * environment). Do not keep "Desktop Folder|"
-				 * in the translation */
-				Q_("Desktop Folder|Desktop"),
+				 * environment). */
+				C_("Desktop Folder", "Desktop"),
 				_("Open the contents of your desktop in a folder"),
 				places_menu,
 				G_CALLBACK (activate_desktop_uri),
@@ -987,10 +987,6 @@ panel_place_menu_item_create_menu (PanelPlaceMenuItem *place_item)
 	if (gconf_name)
 		g_free (gconf_name);
 
-	panel_menu_items_append_from_desktop (places_menu,
-					      "nautilus-cd-burner.desktop",
-					      NULL);
-
 	panel_place_menu_item_append_local_gio (place_item, places_menu);
 	add_menu_separator (places_menu);
 
@@ -1465,11 +1461,11 @@ panel_menu_items_append_lock_logout (GtkWidget *menu)
 		return;
 	/* Below this, we only have log out/shutdown items */
 
-	/* Translators: translate "panel:showusername|1" to anything
+	/* Translators: translate "1" (msgctxt: "panel:showusername") to anything
 	 * but "1" if "Log Out %s" doesn't make any sense in your
 	 * language (where %s is a username).
 	 */
-	translate = Q_("panel:showusername|1");
+	translate = C_("panel:showusername", "1");
 	if (strcmp (translate, "1") == 0) {
 		const char *user_name;
 
@@ -1480,11 +1476,11 @@ panel_menu_items_append_lock_logout (GtkWidget *menu)
 		/* keep those strings in sync with the ones in
 		 * panel-action-button.c */
 		/* Translators: this string is used ONLY if you translated
-		 * "panel:showusername|1" to "1" */
+		 * "1" (msgctxt: "panel:showusername") to "1" */
 		label = g_strdup_printf (_("Log Out %s..."),
 					 g_get_user_name ());
 		/* Translators: this string is used ONLY if you translated
-		 * "panel:showusername|1" to "1" */
+		 * "1" (msgctxt: "panel:showusername") to "1" */
 		tooltip = g_strdup_printf (_("Log out %s of this session to "
 					     "log in as a different user"),
 					   user_name);
@@ -1520,17 +1516,5 @@ void
 panel_menu_item_activate_desktop_file (GtkWidget  *menuitem,
 				       const char *path)
 {
-	GError *error;
-
-	error = NULL;
-	panel_launch_desktop_file (path, NULL,
-				   menuitem_to_screen (menuitem), &error);
-	if (error) {
-		panel_error_dialog (NULL, menuitem_to_screen (menuitem),
-				    "cannot_launch_entry", TRUE,
-				    _("Could not launch menu item"),
-				    error->message);
-
-		g_error_free (error);
-	}
+	panel_launch_desktop_file (path, menuitem_to_screen (menuitem), NULL);
 }
